@@ -16,13 +16,13 @@ def get_package_name():
 python_versions = ["3.10"]
 package = get_package_name()
 gh_deps = {
-    "async_retriever": [],
-    "pygeoogc": ["async_retriever"],
-    "pygeoutils": ["async_retriever", "pygeoogc"],
-    "pynhd": ["async_retriever", "pygeoogc", "pygeoutils"],
-    "py3dep": ["async_retriever", "pygeoogc", "pygeoutils"],
-    "pygeohydro": ["async_retriever", "pygeoogc", "pygeoutils", "pynhd", "hydrosignatures"],
-    "pydaymet": ["async_retriever", "pygeoogc", "pygeoutils", "py3dep"],
+    "async-retriever": [],
+    "pygeoogc": ["async-retriever"],
+    "pygeoutils": ["async-retriever", "pygeoogc"],
+    "pynhd": ["async-retriever", "pygeoogc", "pygeoutils"],
+    "py3dep": ["async-retriever", "pygeoogc", "pygeoutils"],
+    "pygeohydro": ["async-retriever", "pygeoogc", "pygeoutils", "pynhd", "hydrosignatures"],
+    "pydaymet": ["async-retriever", "pygeoogc", "pygeoutils", "py3dep"],
 }
 nox.options.sessions = (
     "pre-commit",
