@@ -4,10 +4,10 @@ from __future__ import annotations
 import itertools
 import math
 import os
+import warnings
 from dataclasses import dataclass
 from pathlib import Path
 from typing import Any, Generator, Mapping, TypeVar, Union
-import warnings
 
 import async_retriever as ar
 import cytoolz as tlz
@@ -49,6 +49,7 @@ __all__ = ["RetrySession", "traverse_json", "streaming_download", "match_crs", "
 
 warnings.filterwarnings("ignore", message=".*too short worker timeout.*")
 
+
 def check_response(resp: str) -> str:
     """Extract error message from a response, if any."""
     try:
@@ -249,7 +250,7 @@ def _prepare_requests_args(
             raise InputTypeError("urls/fnames", "lists of same length")
         files = (Path(f) for f in f_list)
 
-    return url_list, kwd_list, files
+    return url_list, kwd_list, files  # type: ignore[return-value]
 
 
 def streaming_download(
