@@ -110,18 +110,18 @@ class TestREST:
     def test_bysql(self):
         """RESTFul by SQL filter"""
         hr = ArcGISRESTful(self.nhd_url, 2, outformat="json")
-        oids = hr.oids_bysql("PERMANENT_IDENTIFIER IN ('103455178', '103454362', '103453218')")
+        oids = hr.oids_bysql("nhdplusid IN (50000100239005, 50000100235192)")
         resp = hr.get_features(oids, return_m=True)
 
-        assert len(resp[0]["features"]) == 3
+        assert len(resp[0]["features"]) == 2
 
     def test_byfield(self):
         """RESTFul by SQL filter"""
         hr = ArcGISRESTful(self.nhd_url, 2, outformat="json")
-        oids = hr.oids_byfield("PERMANENT_IDENTIFIER", ["103455178", "103454362", "103453218"])
+        oids = hr.oids_byfield("nhdplusid", ["50000100239005", "50000100235192"])
         resp = hr.get_features(oids)
 
-        assert len(resp[0]["features"]) == 3
+        assert len(resp[0]["features"]) == 2
 
 
 def test_retrysession_head():
@@ -129,6 +129,56 @@ def test_retrysession_head():
     session = utils.RetrySession()
     resp = session.head(url)
     assert resp.headers["Content-length"] == "35588"
+    session.close()
+
+
+def test_retrysession_get_length():
+    url = "https://httpbin.org/image/jpeg"
+    session = utils.RetrySession(disable=True)
+    resp = session.get(url, stream=True)
+    assert resp.headers["Content-length"] == "35588"
+    session.close()
+
+
+def test_retrysession_params():
+    url = "https://postman-echo.com"
+    params = {"params_get": "foo"}
+    data = {"data_post": "foo"}
+    session = utils.RetrySession(disable=True)
+
+    get1 = session.get(f"{url}/get", params=params)
+    get2 = session.get(f"{url}/get", payload=params)
+    assert get1.json()["args"] == get2.json()["args"]
+
+    post1 = session.post(f"{url}/post", data=data)
+    post2 = session.post(f"{url}/post", payload=data)
+    assert post1.json()["args"] == post2.json()["args"]
+
+
+def test_retry_ssl():
+    session = utils.RetrySession(ssl=False)
+    base_url = "/".join(
+        (
+            "https://gaftp.epa.gov/epadatacommons/ORD",
+            "NHDPlusLandscapeAttributes/StreamCat/HydroRegions",
+        )
+    )
+    r = session.get(base_url)
+    assert r.status_code == 200
+    session.close()
+
+
+def test_stream():
+    url = "https://freetestdata.com/wp-content/uploads/2021/09/Free_Test_Data_500KB_CSV-1.csv"
+    fname = ogc.streaming_download(url)
+    assert fname.stat().st_size == 512789
+
+    urls = (
+        url,
+        "https://freetestdata.com/wp-content/uploads/2021/09/Free_Test_Data_300KB_CSV-1.csv",
+    )
+    fname = ogc.streaming_download(urls)
+    assert fname[0].stat().st_size == 512789 and fname[1].stat().st_size == 307578
 
 
 @pytest.mark.filterwarnings("ignore:.*Content metadata*.")
@@ -176,8 +226,8 @@ class TestWFS:
         max_nrecords=5,
     )
 
-    def to_df(self, r):
-        return pd.read_csv(io.StringIO(r))
+    def to_df(self, resp):
+        return pd.concat(pd.read_csv(io.StringIO(r)) for r in resp)
 
     def test_byid(self):
         """WFS by ID"""
@@ -190,37 +240,37 @@ class TestWFS:
             "01017000",
             "01017060",
         ]
-        resps = self.wfs.getfeature_byid("staid", stations)
-        df = pd.concat(self.to_df(r) for r in resps)
+        resp = self.wfs.getfeature_byid("staid", stations)
+        df = self.to_df(resp)
         assert set(df.staid.unique()) == {int(s) for s in stations}
 
     def test_bygeom(self):
         """WFS by geometry"""
-        r = self.wfs.getfeature_bygeom(GEO_URB, geo_crs=DEF_CRS, always_xy=False)
-        assert self.to_df(r).shape[0] == 7
+        resp = self.wfs.getfeature_bygeom(GEO_URB, geo_crs=DEF_CRS, always_xy=False)
+        assert self.to_df(resp).shape[0] == 7
 
     def test_bybox(self):
         """WFS by bounding box"""
         bbox = GEO_URB.bounds
-        r = self.wfs.getfeature_bybox(bbox, box_crs=DEF_CRS, always_xy=True)
-        assert self.to_df(r).shape[0] == 7
+        resp = self.wfs.getfeature_bybox(bbox, box_crs=DEF_CRS, always_xy=True)
+        assert self.to_df(resp).shape[0] == 7
 
     def test_byfilter(self):
         """WFS by CQL filter"""
-        r = self.wfs.getfeature_byfilter("staid LIKE '010315%'")
-        assert self.to_df(r).shape[0] == 2
+        resp = self.wfs.getfeature_byfilter("staid LIKE '010315%'")
+        assert self.to_df(resp).shape[0] == 2
 
-    def test_wfs100(self):
-        """WFS 1.0.0 by geom"""
+    def test_wfs110(self):
+        """WFS 1.1.0 by geom"""
         wfs = WFS(
             ServiceURL().wfs.waterdata,
             layer="wmadata:gagesii",
             outformat="json",
-            version="1.0.0",
+            version="1.1.0",
             crs=ALT_CRS,
         )
-        r = wfs.getfeature_bygeom(GEO_URB, geo_crs=DEF_CRS, always_xy=False)
-        assert len(r["features"]) == 7
+        resp = wfs.getfeature_bygeom(GEO_URB, geo_crs=DEF_CRS, always_xy=False)
+        assert len(resp[0]["features"]) == 7
 
 
 def test_decompose():
